@@ -39,7 +39,8 @@ taf.session <- function(sort=FALSE, imports=TRUE, details=FALSE)
                       paste0("[", match(lib, .libPaths()), "]") else "TAF"
     desc$RemoteSha <- if(is.null(desc$RemoteSha))
                         "" else substring(desc$RemoteSha, 1, 7)
-    desc$TAF <- if(basename(dirname(lib)) %in% c("boot","bootstrap")) "*" else ""
+    desc$TAF <- if(basename(dirname(lib)) %in% c("boot","bootstrap")) "*"
+                else ""
     if(identical(desc$Priority, "base"))
       setNames(rep(NA_character_, 5), fields)
     else
